###################################################
### chunk number 1: preliminaries
###################################################
library("modTempEff")
options(prompt = "R> ", continue = "+   ")


###################################################
### chunk number 2: loadlib
###################################################
library("modTempEff")


###################################################
### chunk number 3: data
###################################################
data("dataDeathTemp")
head(dataDeathTemp)


###################################################
### chunk number 4:  eval=FALSE
###################################################
## layout(matrix(c(1,1,2), ncol = 3))
## with(dataDeathTemp, plot(dec1, xlab="day", ylab="no. of deaths"))
## with(dataDeathTemp, plot(mtemp, dec1, xlab="temperature", ylab="no. of deaths"))


###################################################
### chunk number 5: descrPlots
###################################################
layout(matrix(c(1,1,2), ncol = 3))
with(dataDeathTemp, plot(dec1, xlab="day", ylab="no. of deaths"))
with(dataDeathTemp, plot(mtemp, dec1, xlab="temperature", ylab="no. of deaths"))


###################################################
### chunk number 6: 
###################################################
o <- tempeff(dec1 ~ day + factor(dweek) + factor(year) + factor(month) + 
csdl(mtemp, psi = 20, L = c(60, 60)), data = dataDeathTemp, fcontrol = fit.control(display = TRUE))


###################################################
### chunk number 7: 
###################################################
o.noRidge <- update(o, .~. - day - factor(year) - factor(month) + seas(day, 30), fcontrol = fit.control(display = FALSE))


###################################################
### chunk number 8: 
###################################################
o

o.noRidge


###################################################
### chunk number 9: 
###################################################
o.Ridge.l <- update(o.noRidge, ridge = list(cold = "l", heat = "l"))


###################################################
### chunk number 10: 
###################################################
formula(o.Ridge.l)


###################################################
### chunk number 11: 
###################################################
o.Ridge.l4 <- update(o.noRidge, ridge = list(cold = "l^4", heat = "l^4"))
o.Ridge.l4


###################################################
### chunk number 12: 
###################################################
anova(o.noRidge, o.Ridge.l, o.Ridge.l4, test = "Cp")


###################################################
### chunk number 13: 
###################################################
summary(o.Ridge.l4)


###################################################
### chunk number 14: 
###################################################
coef(o.Ridge.l4,L=7)


###################################################
### chunk number 15: DLcurve
###################################################
par(mfcol = c(2, 3))
plot(o.noRidge, new = FALSE)
plot(o.Ridge.l, new = FALSE)
plot(o.Ridge.l4, new = FALSE)


###################################################
### chunk number 16:  eval=FALSE
###################################################
## par(mfcol = c(2, 3))
## plot(o.noRidge, new = FALSE)
## plot(o.Ridge.l, new = FALSE)
## plot(o.Ridge.l4, new = FALSE)


###################################################
### chunk number 17: 
###################################################
o2<-tempeff(dec1 ~ day + factor(dweek) + factor(year) + factor(month) + csdl(mtemp, psi = c(10, 20), L = c(60, 60)), data = dataDeathTemp,
     fcontrol = fit.control(display = TRUE))


###################################################
### chunk number 18: 
###################################################
summary(o2)


###################################################
### chunk number 19: 
###################################################
o2.Ridge.l4 <- update(o.Ridge.l4, psi = c(10, 20), fcontrol = fit.control(it.max = 30))

o2.Ridge.l4


###################################################
### chunk number 20: 
###################################################
anova(o.Ridge.l4, o2.Ridge.l4, test="BIC")


